// 
// Copyright (C) 2007, NinjaTrader LLC <www.ninjatrader.com>.
// NinjaTrader reserves the right to modify or overwrite this NinjaScript component with each release.
//
#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Indicator;
using NinjaTrader.Strategy;
#endregion

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    /// <summary>
    /// Simple strategy that monitors for a breakout from the highets high or the lowest low.
    /// </summary>
    [Description("Simple strategy that monitors for a breakout from the highets high or the lowest low.")]
    public class SampleHighLowCross : Strategy
    {
        #region Variables
		private double highestHigh	= 0;
		private double lowestLow	= 0;
        #endregion

        /// <summary>
        /// This method is used to configure the strategy and is called once before any strategy method is called.
        /// </summary>
        protected override void Initialize()
        {
			// Sets a trail stop of 10 ticks
			SetTrailStop(CalculationMode.Ticks, 10);
			
            CalculateOnBarClose = false;
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {
			// Resets the highest high and lowest low at the start of every new session
			if (Bars.FirstBarOfSession)
			{
				highestHigh = High[0];
				lowestLow = Low[0];
			}
			
			// Stores the highest high and lowest low from the first 15 bars
			if (Bars.BarsSinceSession < 15)
			{
				// If current high is greater than current highest high, set highest high to current high
				if (High[0] > highestHigh)
					highestHigh = High[0];
				
				// If current low is lower than current lowest low, set lowest low to current low
				if (Low[0] < lowestLow)
					lowestLow = Low[0];
			}
			
			/* Entry Condition: After the first 15 bars, submit an entry order when price crosses either the highest high or the lowest low
			if you have no market positions open */
			if (Bars.BarsSinceSession > 15 && Position.MarketPosition == MarketPosition.Flat)
			{
				// If price crosses above the highest high, enter long
				if (CrossAbove(Close, highestHigh, 1))
					EnterLong();
				
				// If price crosses below the lowest low, enter short
				else if (CrossBelow(Close, lowestLow, 1))
					EnterShort();
			}
        }
    }
}
